@@ -24,6 +24,12 @@ const (
 	DefaultDashboardCpuLimit      = "500m"
 	DefaultDashboardCpuRequest    = "100m"
 
+	// Gateway
+	DefaultGatewayMemoryLimit   = "256Mi"
+	DefaultGatewayMemoryRequest = "64Mi"
+	DefaultGatewayCpuLimit      = "500m"
+	DefaultGatewayCpuRequest    = "50m"
+
 	// PluginRegistry
 	DefaultPluginRegistryMemoryLimit                          = "256Mi"
 	DefaultPluginRegistryMemoryLimitEmbeddedOpenVSXRegistry   = "4Gi"
@@ -99,6 +105,7 @@ const (
 	PerWorkspacePVCStorageStrategy = "per-workspace"
 	EphemeralPVCStorageStrategy    = "ephemeral"
 	CommonPVCStorageStrategy       = "common"
+	DefaultDeploymentStrategy      = "Recreate"
 	DefaultAutoProvision           = true
 	DefaultWorkspaceJavaOpts       = "-XX:MaxRAM=150m -XX:MaxRAMFraction=2 -XX:+UseParallelGC " +
 		"-XX:MinHeapFreeRatio=10 -XX:MaxHeapFreeRatio=20 -XX:GCTimeRatio=4 -XX:AdaptiveSizePolicyWeight=90 " +
@@ -123,6 +130,7 @@ const (
 	CheFlavor             = "che"
 	CheEclipseOrg         = "che.eclipse.org"
 	InstallOrUpdateFailed = "InstallOrUpdateFailed"
+	FinalizerSuffix       = "finalizers.che.eclipse.org"
 
 	// DevWorkspace
 	DevWorkspaceServiceAccountName = "devworkspace-controller-serviceaccount"
