@@ -75,6 +75,25 @@ func (d *DashboardReconciler) getDashboardDeploymentSpec(ctx *chetypes.DeployCon
 			Value: fmt.Sprintf("http://%s.%s.svc:8080/api", deploy.CheServiceName, ctx.CheCluster.Namespace)},
 	)
 
+	if !ctx.CheCluster.Spec.Components.DevfileRegistry.DisableInternalRegistry {
+		envVars = append(envVars,
+			corev1.EnvVar{
+				Name:  "CHE_WORKSPACE_DEVFILE__REGISTRY__INTERNAL__URL",
+				Value: fmt.Sprintf("http://%s.%s.svc:8080", constants.DevfileRegistryName, ctx.CheCluster.Namespace)},
+		)
+	}
+
+	if !ctx.CheCluster.Spec.Components.PluginRegistry.DisableInternalRegistry {
+		envVars = append(envVars,
+			corev1.EnvVar{
+				Name:  "CHE_WORKSPACE_PLUGIN__REGISTRY__INTERNAL__URL",
+				Value: fmt.Sprintf("http://%s.%s.svc:8080/v3", constants.PluginRegistryName, ctx.CheCluster.Namespace)},
+		)
+	}
+
+	// Mount CheCluster default values
+	envVars = append(envVars, utils.GetEnvsByRegExp("^CHE_DEFAULT_SPEC.*")...)
+
 	if utils.IsK8SResourceServed(ctx.ClusterAPI.DiscoveryClient, ConsoleLinksResourceName) {
 		envVars = append(envVars,
 			corev1.EnvVar{
@@ -132,7 +151,7 @@ func (d *DashboardReconciler) getDashboardDeploymentSpec(ctx *chetypes.DeployCon
 								},
 							},
 							ReadinessProbe: &corev1.Probe{
-								Handler: corev1.Handler{
+								ProbeHandler: corev1.ProbeHandler{
 									HTTPGet: &corev1.HTTPGetAction{
 										Path: "/",
 										Port: intstr.IntOrString{
@@ -149,7 +168,7 @@ func (d *DashboardReconciler) getDashboardDeploymentSpec(ctx *chetypes.DeployCon
 								PeriodSeconds:       10,
 							},
 							LivenessProbe: &corev1.Probe{
-								Handler: corev1.Handler{
+								ProbeHandler: corev1.ProbeHandler{
 									HTTPGet: &corev1.HTTPGetAction{
 										Path: "/",
 										Port: intstr.IntOrString{
