@@ -14,8 +14,6 @@ package server
 import (
 	"os"
 
-	"k8s.io/utils/pointer"
-
 	"k8s.io/apimachinery/pkg/api/resource"
 
 	"github.com/eclipse-che/che-operator/pkg/common/chetypes"
@@ -38,6 +36,11 @@ import (
 )
 
 func TestDeployment(t *testing.T) {
+	memoryRequest := resource.MustParse("150Mi")
+	cpuRequest := resource.MustParse("150m")
+	memoryLimit := resource.MustParse("250Mi")
+	cpuLimit := resource.MustParse("250m")
+
 	type testCase struct {
 		name          string
 		initObjects   []runtime.Object
@@ -82,12 +85,12 @@ func TestDeployment(t *testing.T) {
 										Name: defaults.GetCheFlavor(),
 										Resources: &chev2.ResourceRequirements{
 											Requests: &chev2.ResourceList{
-												Memory: resource.MustParse("150Mi"),
-												Cpu:    resource.MustParse("150m"),
+												Memory: &memoryRequest,
+												Cpu:    &cpuRequest,
 											},
 											Limits: &chev2.ResourceList{
-												Memory: resource.MustParse("250Mi"),
-												Cpu:    resource.MustParse("250m"),
+												Memory: &memoryLimit,
+												Cpu:    &cpuLimit,
 											},
 										},
 									},
@@ -205,7 +208,7 @@ func TestMountBitBucketServerOAuthEnvVar(t *testing.T) {
 			value = utils.GetEnvByName("CHE_OAUTH1_BITBUCKET_PRIVATEKEYPATH", container.Env)
 			assert.Equal(t, testCase.expectedPrivateKeyPath, value)
 
-			value = utils.GetEnvByName("CHE_OAUTH1_BITBUCKET_ENDPOINT", container.Env)
+			value = utils.GetEnvByName("CHE_OAUTH_BITBUCKET_ENDPOINT", container.Env)
 			assert.Equal(t, testCase.expectedOAuthEndpoint, value)
 
 			volume := test.FindVolume(deployment.Spec.Template.Spec.Volumes, "bitbucket-oauth-config")
@@ -303,13 +306,14 @@ func TestMountBitbucketOAuthEnvVar(t *testing.T) {
 
 func TestMountGitHubOAuthEnvVar(t *testing.T) {
 	type testCase struct {
-		name                  string
-		initObjects           []runtime.Object
-		expectedIdKeyPath     string
-		expectedSecretKeyPath string
-		expectedOAuthEndpoint string
-		expectedVolume        corev1.Volume
-		expectedVolumeMount   corev1.VolumeMount
+		name                              string
+		initObjects                       []runtime.Object
+		expectedIdKeyPath                 string
+		expectedSecretKeyPath             string
+		expectedOAuthEndpoint             string
+		expectedDisableSubdomainIsolation string
+		expectedVolume                    corev1.Volume
+		expectedVolumeMount               corev1.VolumeMount
 	}
 
 	testCases := []testCase{
@@ -329,8 +333,9 @@ func TestMountGitHubOAuthEnvVar(t *testing.T) {
 							"app.kubernetes.io/component": "oauth-scm-configuration",
 						},
 						Annotations: map[string]string{
-							"che.eclipse.org/oauth-scm-server":    "github",
-							"che.eclipse.org/scm-server-endpoint": "endpoint_1",
+							"che.eclipse.org/oauth-scm-server":                       "github",
+							"che.eclipse.org/scm-server-endpoint":                    "endpoint_1",
+							"che.eclipse.org/scm-github-disable-subdomain-isolation": "true",
 						},
 					},
 					Data: map[string][]byte{
@@ -339,9 +344,10 @@ func TestMountGitHubOAuthEnvVar(t *testing.T) {
 					},
 				},
 			},
-			expectedIdKeyPath:     "/che-conf/oauth/github/id",
-			expectedSecretKeyPath: "/che-conf/oauth/github/secret",
-			expectedOAuthEndpoint: "endpoint_1",
+			expectedIdKeyPath:                 "/che-conf/oauth/github/id",
+			expectedSecretKeyPath:             "/che-conf/oauth/github/secret",
+			expectedOAuthEndpoint:             "endpoint_1",
+			expectedDisableSubdomainIsolation: "true",
 			expectedVolume: corev1.Volume{
 				Name: "github-oauth-config",
 				VolumeSource: corev1.VolumeSource{
@@ -376,6 +382,9 @@ func TestMountGitHubOAuthEnvVar(t *testing.T) {
 			value = utils.GetEnvByName("CHE_INTEGRATION_GITHUB_OAUTH__ENDPOINT", container.Env)
 			assert.Equal(t, testCase.expectedOAuthEndpoint, value)
 
+			value = utils.GetEnvByName("CHE_INTEGRATION_GITHUB_DISABLE__SUBDOMAIN__ISOLATION", container.Env)
+			assert.Equal(t, testCase.expectedDisableSubdomainIsolation, value)
+
 			volume := test.FindVolume(deployment.Spec.Template.Spec.Volumes, "github-oauth-config")
 			assert.NotNil(t, volume)
 			assert.Equal(t, testCase.expectedVolume, volume)
@@ -554,185 +563,3 @@ func TestMountGitLabOAuthEnvVar(t *testing.T) {
 		})
 	}
 }
-
-func TestMountGitHubDisableSubdomainIsolationEnvVar(t *testing.T) {
-	type testCase struct {
-		name                              string
-		cheCluster                        *chev2.CheCluster
-		initObjects                       []runtime.Object
-		expectedDisableSubdomainIsolation string
-	}
-
-	testCases := []testCase{
-		{
-			name: "Test #1",
-			cheCluster: &chev2.CheCluster{
-				ObjectMeta: metav1.ObjectMeta{
-					Name:      "eclipse-che",
-					Namespace: "eclipse-che",
-				},
-				Spec: chev2.CheClusterSpec{
-					GitServices: chev2.CheClusterGitServices{
-						GitHub: []chev2.GitHubService{
-							{
-								DisableSubdomainIsolation: pointer.BoolPtr(true),
-								SecretName:                "github-oauth-config",
-							},
-						},
-					},
-				},
-			},
-			initObjects: []runtime.Object{
-				&corev1.Secret{
-					TypeMeta: metav1.TypeMeta{
-						Kind:       "Secret",
-						APIVersion: "v1",
-					},
-					ObjectMeta: metav1.ObjectMeta{
-						Name:      "github-oauth-config",
-						Namespace: "eclipse-che",
-						Labels: map[string]string{
-							"app.kubernetes.io/part-of":   "che.eclipse.org",
-							"app.kubernetes.io/component": "oauth-scm-configuration",
-						},
-						Annotations: map[string]string{
-							"che.eclipse.org/oauth-scm-server": "github",
-						},
-					},
-				},
-			},
-			expectedDisableSubdomainIsolation: "true",
-		},
-		{
-			name: "Test #2",
-			cheCluster: &chev2.CheCluster{
-				ObjectMeta: metav1.ObjectMeta{
-					Name:      "eclipse-che",
-					Namespace: "eclipse-che",
-				},
-				Spec: chev2.CheClusterSpec{
-					GitServices: chev2.CheClusterGitServices{
-						GitHub: []chev2.GitHubService{
-							{
-								DisableSubdomainIsolation: pointer.BoolPtr(false),
-								SecretName:                "github-oauth-config",
-							},
-						},
-					},
-				},
-			},
-			initObjects: []runtime.Object{
-				&corev1.Secret{
-					TypeMeta: metav1.TypeMeta{
-						Kind:       "Secret",
-						APIVersion: "v1",
-					},
-					ObjectMeta: metav1.ObjectMeta{
-						Name:      "github-oauth-config",
-						Namespace: "eclipse-che",
-						Labels: map[string]string{
-							"app.kubernetes.io/part-of":   "che.eclipse.org",
-							"app.kubernetes.io/component": "oauth-scm-configuration",
-						},
-						Annotations: map[string]string{
-							"che.eclipse.org/oauth-scm-server": "github",
-						},
-					},
-				},
-			},
-			expectedDisableSubdomainIsolation: "false",
-		},
-		{
-			name: "Test #3",
-			cheCluster: &chev2.CheCluster{
-				ObjectMeta: metav1.ObjectMeta{
-					Name:      "eclipse-che",
-					Namespace: "eclipse-che",
-				},
-				Spec: chev2.CheClusterSpec{
-					GitServices: chev2.CheClusterGitServices{
-						GitHub: []chev2.GitHubService{
-							{
-								SecretName: "github-oauth-config",
-							},
-						},
-					},
-				},
-			},
-			initObjects: []runtime.Object{
-				&corev1.Secret{
-					TypeMeta: metav1.TypeMeta{
-						Kind:       "Secret",
-						APIVersion: "v1",
-					},
-					ObjectMeta: metav1.ObjectMeta{
-						Name:      "github-oauth-config",
-						Namespace: "eclipse-che",
-						Labels: map[string]string{
-							"app.kubernetes.io/part-of":   "che.eclipse.org",
-							"app.kubernetes.io/component": "oauth-scm-configuration",
-						},
-						Annotations: map[string]string{
-							"che.eclipse.org/oauth-scm-server": "github",
-						},
-					},
-				},
-			},
-			expectedDisableSubdomainIsolation: "",
-		},
-		{
-			name: "Test #4",
-			cheCluster: &chev2.CheCluster{
-				ObjectMeta: metav1.ObjectMeta{
-					Name:      "eclipse-che",
-					Namespace: "eclipse-che",
-				},
-				Spec: chev2.CheClusterSpec{
-					GitServices: chev2.CheClusterGitServices{
-						GitHub: []chev2.GitHubService{
-							{
-								SecretName:                "NOT-FOUND-SECRET",
-								DisableSubdomainIsolation: pointer.BoolPtr(true),
-							},
-						},
-					},
-				},
-			},
-			initObjects: []runtime.Object{
-				&corev1.Secret{
-					TypeMeta: metav1.TypeMeta{
-						Kind:       "Secret",
-						APIVersion: "v1",
-					},
-					ObjectMeta: metav1.ObjectMeta{
-						Name:      "github-oauth-config",
-						Namespace: "eclipse-che",
-						Labels: map[string]string{
-							"app.kubernetes.io/part-of":   "che.eclipse.org",
-							"app.kubernetes.io/component": "oauth-scm-configuration",
-						},
-						Annotations: map[string]string{
-							"che.eclipse.org/oauth-scm-server": "github",
-						},
-					},
-				},
-			},
-			expectedDisableSubdomainIsolation: "",
-		},
-	}
-
-	for _, testCase := range testCases {
-		t.Run(testCase.name, func(t *testing.T) {
-			ctx := test.GetDeployContext(testCase.cheCluster, testCase.initObjects)
-
-			server := NewCheServerReconciler()
-			deployment, err := server.getDeploymentSpec(ctx)
-			assert.Nil(t, err, "Unexpected error %v", err)
-
-			container := &deployment.Spec.Template.Spec.Containers[0]
-
-			value := utils.GetEnvByName("CHE_INTEGRATION_GITHUB_DISABLE__SUBDOMAIN__ISOLATION", container.Env)
-			assert.Equal(t, testCase.expectedDisableSubdomainIsolation, value)
-		})
-	}
-}
