@@ -14,20 +14,23 @@ package server
 import (
 	"fmt"
 
+	"github.com/eclipse-che/che-operator/pkg/common/chetypes"
+	"github.com/eclipse-che/che-operator/pkg/common/constants"
+	defaults "github.com/eclipse-che/che-operator/pkg/common/operator-defaults"
 	"github.com/eclipse-che/che-operator/pkg/deploy"
 	corev1 "k8s.io/api/core/v1"
 )
 
-func getComponentName(ctx *deploy.DeployContext) string {
-	return deploy.DefaultCheFlavor(ctx.CheCluster)
+func getComponentName(ctx *chetypes.DeployContext) string {
+	return defaults.GetCheFlavor()
 }
 
-func getOAuthConfig(ctx *deploy.DeployContext, oauthProvider string) (*corev1.Secret, error) {
+func getOAuthConfig(ctx *chetypes.DeployContext, oauthProvider string) (*corev1.Secret, error) {
 	secrets, err := deploy.GetSecrets(ctx, map[string]string{
-		deploy.KubernetesPartOfLabelKey:    deploy.CheEclipseOrg,
-		deploy.KubernetesComponentLabelKey: deploy.OAuthScmConfiguration,
+		constants.KubernetesPartOfLabelKey:    constants.CheEclipseOrg,
+		constants.KubernetesComponentLabelKey: constants.OAuthScmConfiguration,
 	}, map[string]string{
-		deploy.CheEclipseOrgOAuthScmServer: oauthProvider,
+		constants.CheEclipseOrgOAuthScmServer: oauthProvider,
 	})
 
 	if err != nil {
